@@ -60,8 +60,9 @@ def to_timestamp(d):
     """
     Convert a sting or a timestamp to a timestamp. This is a dirty fix necessary
     because the /dataset/list route return timestamps but /dataset/search
-    returns strings.
+    returns strings in older versions of the lookup server (before 0.15.0).
     """
+    print(d)
     if type(d) is str:
         try:
             with time_locale('C'):
@@ -206,7 +207,9 @@ class SignalHandler:
     def _refresh_results(self):
         results_widget = self.builder.get_object('search-results')
         statusbar_widget = self.builder.get_object('main-statusbar')
-        statusbar_widget.push(0, f'{len(self.datasets)} datasets')
+        statusbar_widget.push(0, f'{len(self.datasets)} datasets - '
+                                 f'Connect to lookup server version '
+                                 f"{self.server_config['version']}")
 
         if len(self.datasets) == 0:
             self.main_stack.set_visible_child(
@@ -307,6 +310,7 @@ class SignalHandler:
                                    self.settings.password)
         try:
             await self.lookup.connect()
+            self.server_config = await self.lookup.config()
             self.datasets = await self.lookup.all()
         except Exception as e:
             self.error_label.set_text(str(e))
